<?php
/**
 * @package Dashboard.Signature
 */
/*
 * Plugin Name: Dashboard.Signature
 * Plugin URI: https://presswith.thecruzat.com
 * Description: Personalize a WordPress dashboard for your users by adding custom content into the left and right footer areas.
 * Version: 1.0.0
 * Author: Dan Cruzat
 * Author URI: https://thecruzat.com
 * License: GPLv2 or later
 * TextDomain: dashboard-signature
 */

# Add Dash.Sig to Settings panel
function add_dash_sig()
{
    add_options_page(
        __('Dashboard.Signature', 'textdomain' ),
        __('Dash.Sig', 'textdomain' ),
        'manage_options',
        'dash-sig',
        'dash_sig_page',
        100
    );
}
add_action('admin_menu', 'add_dash_sig');

# Dash.Sig main layout
function dash_sig_page()
{
    ?>
    <div class='wrap'>
        <div id='icon-options-general' class='icon32'></div>
        <h1>Dashboard.Signature</h1>
        <p>Personalize this dashboard for your users by adding custom content into footer areas, leave blank for default.</p>
        <form method='post' action='options.php'>
        <?php
            settings_fields('dash_sig_form');
            do_settings_sections('dash-sig');
            submit_button();
        ?>
        </form>
    </div>
    <?php
}

# Dash.Sig form setup
function dash_sig_options()
{
    add_settings_section('dash_sig_form', '', 'display_dsform_options_content', 'dash-sig');

    add_settings_field('dash_sig_form_left', 'Admin footer text<br>(bottom left)', 'display_dash_sig_form_left', 'dash-sig', 'dash_sig_form');
    add_settings_field('dash_sig_form_right', 'Version footer text<br>(bottom right)', 'display_dash_sig_form_right', 'dash-sig', 'dash_sig_form');

    register_setting('dash_sig_form', 'dash_sig_form_left', array( 'default' => 'He\'s putting us on the train to Squaresville, Mona.' ));
    register_setting('dash_sig_form', 'dash_sig_form_right', array( 'default' => '<a href="//presswith.thecruzat.com" target="_blank" title="see more juicy WordPress gizmos from Dan Cruzat">presswith.thecruzat.com</a>' ));
}
add_action('admin_init', 'dash_sig_options');

# Dash.Sig form head
function display_dsform_options_content(){}

# Dash.Sig form element, bottom left
function display_dash_sig_form_left()
{
    ?>
    <textarea style='width: 100%; max-width: 640px;' id='dash_sig_form_left' name='dash_sig_form_left'><?php echo esc_textarea( get_option('dash_sig_form_left') ); ?></textarea>
    <?php
}

# Dash.Sig form element, bottom right
function display_dash_sig_form_right()
{
    ?>
    <textarea style='width: 100%; max-width: 640px;' id='dash_sig_form_right' name='dash_sig_form_right'><?php echo esc_textarea( get_option('dash_sig_form_right') ); ?></textarea>
    <?php
}

# Retrieve Dash.Sig form values
$dash_sig_l = get_option('dash_sig_form_left');
$dash_sig_r = get_option('dash_sig_form_right');

# If values are set, call functions to edit
if($dash_sig_l !== NULL && $dash_sig_l !== '') {    add_filter('admin_footer_text', 'dash_sig_flip_admin');     }
if($dash_sig_r !== NULL && $dash_sig_r !== '') {    add_filter('update_footer','dash_sig_flip_version',11);    }

# Flip admin footer content, bottom left
function dash_sig_flip_admin()
{
    echo __( get_option('dash_sig_form_left') );
}

# Flip version footer content, bottom right
function dash_sig_flip_version()
{
    echo __( get_option('dash_sig_form_right') );
}

# Redirect user following plugin activation
function dash_sig_activation_redirect( $plugin )
{
    if( $plugin == plugin_basename(__FILE__) ) {
        exit( wp_redirect( admin_url( 'options-general.php?page=dash-sig' ) ) );
    }
}
add_action( 'activated_plugin', 'dash_sig_activation_redirect' );
